/*
 * dbtool - a simple but powerfull commandline interface
 *      to the GNU gdbm system, usefull for shellscripts
 *      which needs a database for data storage.
 *
 * Copyright (c) 2001 Thomas Linden, <tom@daemon.de>
 * All Rights Reserved.      Released under the GPL.
 *
 * $Id: main.cc,v 1.5 2001/04/20 19:34:53 scip Exp $
 */


#ifdef HAVE_BERKELEY
# include <db_cxx.h>
#endif

#include "dbtool.h"




int main(int argc, char *argv[]) {
  Config config(argc, argv);
  Engine en;
  string pkg = PACKAGE;

  if(config.parse() != 0) {
    cerr << config.usage << ".\n";;
    exit(1);
  }
  else {
    switch(config.command) {
    case 'i':
      /* insert */
      if(config.key == "") {
	cerr << pkg << ": key required\n";
	exit(1);
      }
      en.insert(config);
      break;
    case 'd':
      /* dump */
      en.dump(config);
      break;
    case 'I':
      en.stdin(config);
      break;
    case 's':
      /* select */
      if(config.key == "") {
	cerr << pkg << ": key required\n";
	exit(1);
      }
      en.select(config);
      break;
    case 'S':
      /* regexp select */
      if(config.key == "") {
	cerr << pkg << ": key (regexp) required\n";
	exit(1);
      }
      en.regexp(config);
      break;
    case 'r':
      /* remove */
      if(config.key == "") {
	cerr << pkg << ": key required\n";
	exit(1);
      }
      en.remove(config);
      break;
    case 'u':
      /* update */
      if(config.key == "") {
	cerr << pkg << ": key required\n";
	exit(1);
      }
      en.update(config);
      break;
    case 'v':
      /* version */
      cerr << "This is " << pkg << " version " << VERSION << " by Thomas Linden.\n";
      exit(1);
    case 'h':
      /* usage/help */
      cerr << config.usage << ".\n";
      exit(1);
    }
  }
  exit(0);
}





